#
# spec file for package kitinerary
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
Name:           kitinerary
Version:        20.04.2
Release:        bp153.2.2.1
Summary:        Data model and extraction system for travel reservations
License:        LGPL-2.1-or-later
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  kf5-filesystem
BuildRequires:  libopenssl-devel
BuildRequires:  libpoppler-qt5-devel
BuildRequires:  libxml2-devel
BuildRequires:  zlib-devel
BuildRequires:  cmake(KF5CalendarCore)
BuildRequires:  cmake(KF5Contacts)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5Mime)
BuildRequires:  cmake(KPimPkPass)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5Test)
Requires:       libKPimItinerary5 = %{version}
%if %{with lang}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
%if 0%{?suse_version} > 1500
BuildRequires:  libphonenumber-devel
BuildRequires:  cmake(ZXing)
%endif

%description
Kitinerary is a library which provides a data model and a system to extract information
from travel reservations. The model can then be reused in other applications.

%package -n libKPimItinerary5
Summary:        Data model and extraction system for travel reservations
Group:          System/Libraries
Recommends:     %{name}
Recommends:     libKPimItinerary5-lang

%description -n libKPimItinerary5
Kitinerary is a library which provides a data model and a system to extract information
from travel reservations. The model can then be reused in other applications.
This package contains the library itself.

%package devel
Summary:        Development files for kitinerary
Group:          Development/Libraries/KDE
Requires:       libKPimItinerary5 = %{version}
Requires:       cmake(KF5CalendarCore)
Requires:       cmake(KF5Contacts)
Requires:       cmake(KF5Mime)
Requires:       cmake(KPimPkPass)
Requires:       cmake(Qt5Gui)

%description devel
This package contains all necessary include files and libraries needed
to build programs that use the kitinerary library.

%lang_package -n libKPimItinerary5

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %cmake_build

%install
  %kf5_makeinstall -C build
  %if %{with lang}
    %find_lang %{name} --with-man --with-qt --all-name
  %endif

%post -n libKPimItinerary5 -p /sbin/ldconfig
%postun -n libKPimItinerary5 -p /sbin/ldconfig

%files
%license COPYING.LIB
%{_kf5_libexecdir}/kitinerary-extractor
%dir %{_kf5_sharedir}/mime
%dir %{_kf5_sharedir}/mime/packages
%{_kf5_sharedir}/mime/packages/application-vnd-kde-itinerary.xml

%files -n libKPimItinerary5
%license COPYING.LIB
%{_kf5_libdir}/libKPimItinerary.so.*
%{_kf5_debugdir}/*.categories

%files devel
%dir %{_includedir}/KPim/
%{_includedir}/KPim/KItinerary/
%{_includedir}/KPim/kitinerary/
%{_includedir}/KPim/kitinerary_version.h
%{_kf5_cmakedir}/KPimItinerary/
%{_kf5_libdir}/libKPimItinerary.so

%if %{with lang}
%files -n libKPimItinerary5-lang -f %{name}.lang
%endif

%changelog
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Fix includes. Try to make it compile under windows
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- No code change since 20.03.90
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * Fix extractor deduplication
  * Convert time to calendar timezone before taking the date
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes since 19.12.3, only listing bugfixes:
  * Improve description for hotel booking ical events (kde#416444)
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * Handle language variants in the Vueling extractor
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- Changes since 19.12.1:
  * Fix merging of flight reservations with different IATA BCBP data
  * Deal with the German language variant of Trenitalia tickets
  * Move extractor engine capabilities string to the library
  * Add walking distance accuracy level for the location comparison
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Too many changes to list here.
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Too many changes to list here.
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Changes since 19.11.80:
  * Update knowledge base databases from Wikidata
  * Silence debug output
  * Do not fail on DB tickets with VDV barcodes
  * Make RegioJet date/time patterns more strict
  * Fix nullptr dereference when PDF loading fails
  * Add a RAII wrapper around Poppler's globalParams
  * Make the Poppler version checking a bit more scalable
  * Don't initialize MemoryCalendar with an invalid timezone
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes to list here.
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- Changes since 19.08.2:
  * Better end time default for restaurant reservations without an end time
  * Fix compatibility with Poppler 0.82
* Thu Oct 17 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update build requirements, add missing Requires to devel package
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Changes since 19.08.1:
  * Fix UTC conversion during date/time parsing
  * Add another date format fallback for a new Lufthansa date format
  * Add unit test for JSON-LD date/time parsing
  * Fix date parsing in SNCF confirmation emails
  * QLatin1Literal => QLatin1String to fix compilation with Qt 5.14
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- No code change since 19.08.0
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * Adapt to KCalendarCore namespace change
  * Update Wikidata data tables for 19.08 release
  * Hotfix for ZXing master breaking pure QR code decoding for some reason
  * Fix another method name typo
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- No code changes since 19.04.2
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- Changes since 19.04.1:
  * Check IATA BCBP input a bit more strictly (kde#407895)
  * Add German language support for the A&O hostel extractor
  * Handle line continuations in Deutsche Bahn tickets
  * More robust line continuation detection for the DB extractor
  * Keep the ticket token in the RCT2 extractor
  * Fix PNR extraction for some sort of DB/ÖBB cross-over ticket
  * PNR is optional in SNCF booking confirmations (kde#404451)
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- No code changes since 19.04.0
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * Fix extraction of arrival/departure time for Brussels Airlines
  * Add airline IATA code as trigger criteria for Brussels Airlines too
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Don't block airport name disambiguation on the "international" fragment
  * Make the email parser handle all kinds of line breaks
  * Normalize all place names, not just those of airports
  * Extend Amadeus filter
  * Support one more Lufthansa variation of this
  * Support English BCD ical files too
  * Fix compile, Qt5Widgets_VERSION isn't defined, use Qt5Core_VERSION instead
  * Workaround qt5.13 bug
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * No code changes since 18.12.0
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * Add missing comparison operators
  * Fix compatibility with Poppler 0.72
  * Fix FCM extractor for single digit flight numbers
  * Remove obsolete todo
  * Improve airport lookup by considering alternative umlaut transliterations
  * Cleanup airport name lookup code a bit
  * Fix flight calendar entries when IATA airport code is missing
  * Add arrival terminal property
  * Add Easyjet extractor
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * GBool -> bool
  * Relax leading space offset detection for international tickets
  * Auto-detect leading space in compact/international DB tickets
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Fri Sep  7 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Run the generic IATA BCBP extractor also for Vueling
  * Make the pdfdocumenttest pass without Poppler
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Fix binary Aztec barcode encoding for ticket tokens
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * None
* Thu Apr 12 2018 lbeltrame@kde.org
- Initial package
